shithub: pokecrystal

Download patch

ref: 14a244ad3a2e66de9690c11e6e1b5c488408427a
parent: b423e3b90bb85ef7e5cf501d832db707c9b1fde3
author: Remy Oukaour <remy.oukaour@gmail.com>
date: Fri Dec 22 17:56:21 EST 2017

IsHM is not used within home/names.asm; group it with the other HM routines+data

--- a/home/names.asm
+++ b/home/names.asm
@@ -258,16 +258,6 @@
 	db "@"
 ; 34df
 
-IsHM:: ; 34df
-	cp HM01
-	jr c, .NotHM
-	scf
-	ret
-.NotHM:
-	and a
-	ret
-; 34e7
-
 INCLUDE "home/hm_moves.asm"
 
 GetMoveName:: ; 34f8
--- a/home/hm_moves.asm
+++ b/home/hm_moves.asm
@@ -1,4 +1,14 @@
-;  HM moves can't be forgotten
+; HM moves can't be forgotten
+
+IsHM:: ; 34df
+	cp HM01
+	jr c, .NotHM
+	scf
+	ret
+.NotHM:
+	and a
+	ret
+; 34e7
 
 IsHMMove:: ; 34e7
 	ld hl, .HMMoves